@@ -19,7 +19,9 @@ stemmer = stemmer("english")
 import os
 os.chdir(os.path.dirname(__file__))
 
-preproc_cpp = cppimport.imp("../hdp_preproc")
+arg = os.getcwd()
+
+preproc_cpp = cppimport.imp("hdp_preproc")
 
 
 #### MAIN FUNCTIONS ####
